@@ -1,4 +1,4 @@
-//          Copyright Maarten L. Hekkelman, 2020
+//       Copyright Maarten L. Hekkelman, 2025-2026
 // Distributed under the Boost Software License, Version 1.0.
 //    (See accompanying file LICENSE_1_0.txt or copy at
 //          http://www.boost.org/LICENSE_1_0.txt)
@@ -8,8 +8,6 @@
 /// \file
 /// A simple std::streambuf implementation that wraps around const char* data.
 
-#include <zeep/config.hpp>
-
 #include <cassert>
 #include <cstring>
 
@@ -27,26 +25,28 @@ namespace zeep
 class char_streambuf : public std::streambuf
 {
   public:
-
 	/// \brief constructor taking a \a buffer and a \a length
-	char_streambuf(const char* buffer, size_t length)
-		: m_begin(buffer), m_end(buffer + length), m_current(buffer)
+	char_streambuf(const char *buffer, size_t length)
+		: m_begin(buffer)
+		, m_end(buffer + length)
+		, m_current(buffer)
 	{
-		assert(std::less_equal<const char*>()(m_begin, m_end));
+		assert(std::less_equal<>()(m_begin, m_end));
 	}
 
 	/// \brief constructor taking a \a buffer using the standard strlen to determine the length
-	char_streambuf(const char* buffer)
-		: m_begin(buffer), m_end(buffer + strlen(buffer)), m_current(buffer)
+	char_streambuf(const char *buffer)
+		: m_begin(buffer)
+		, m_end(buffer + strlen(buffer))
+		, m_current(buffer)
 	{
 	}
 
-	char_streambuf(const char_streambuf&) = delete;
-	char_streambuf &operator=(const char_streambuf&) = delete;
+	char_streambuf(const char_streambuf &) = delete;
+	char_streambuf &operator=(const char_streambuf &) = delete;
 
-  private:
-
-	int_type underflow()
+  protected:
+	int_type underflow() override
 	{
 		if (m_current == m_end)
 			return traits_type::eof();
@@ -54,7 +54,7 @@ class char_streambuf : public std::streambuf
 		return traits_type::to_int_type(*m_current);
 	}
 
-	int_type uflow()
+	int_type uflow() override
 	{
 		if (m_current == m_end)
 			return traits_type::eof();
@@ -62,7 +62,7 @@ class char_streambuf : public std::streambuf
 		return traits_type::to_int_type(*m_current++);
 	}
 
-	int_type pbackfail(int_type ch)
+	int_type pbackfail(int_type ch) override
 	{
 		if (m_current == m_begin or (ch != traits_type::eof() and ch != m_current[-1]))
 			return traits_type::eof();
@@ -70,13 +70,13 @@ class char_streambuf : public std::streambuf
 		return traits_type::to_int_type(*--m_current);
 	}
 
-	std::streamsize showmanyc()
+	std::streamsize showmanyc() override
 	{
-		assert(std::less_equal<const char*>()(m_current, m_end));
+		assert(std::less_equal<>()(m_current, m_end));
 		return m_end - m_current;
 	}
 
-	pos_type seekoff(std::streambuf::off_type off, std::ios_base::seekdir dir, std::ios_base::openmode /*which*/)
+	pos_type seekoff(std::streambuf::off_type off, std::ios_base::seekdir dir, std::ios_base::openmode /*which*/) override
 	{
 		switch (dir)
 		{
@@ -91,27 +91,27 @@ class char_streambuf : public std::streambuf
 			case std::ios_base::cur:
 				m_current += off;
 				break;
-			
+
 			default:
 				break;
 		}
 
 		if (m_current < m_begin)
 			m_current = m_begin;
-		
+
 		if (m_current > m_end)
 			m_current = m_end;
 
 		return m_current - m_begin;
 	}
 
-	pos_type seekpos(std::streambuf::pos_type pos, std::ios_base::openmode /*which*/)
+	pos_type seekpos(std::streambuf::pos_type pos, std::ios_base::openmode /*which*/) override
 	{
 		m_current = m_begin + pos;
 
 		if (m_current < m_begin)
 			m_current = m_begin;
-		
+
 		if (m_current > m_end)
 			m_current = m_end;
 
@@ -119,9 +119,9 @@ class char_streambuf : public std::streambuf
 	}
 
   private:
-	const char* const m_begin;
-	const char* const m_end;
-	const char* m_current;
+	const char *const m_begin;
+	const char *const m_end;
+	const char *m_current;
 };
-	
+
 } // namespace zeep
